'use strict';

Object.defineProperty(exports, "__esModule", {
	value: true
});
exports.isArguments = isArguments;
exports.default = spread;
function isArguments(node) {
	return node.type === 'Identifier' && node.name === 'arguments';
}

function spread(code, elements, start, argumentsArrayAlias, isNew) {
	var i = elements.length;
	var firstSpreadIndex = -1;

	while (i--) {
		var _element = elements[i];
		if (_element && _element.type === 'SpreadElement') {
			if (isArguments(_element.argument)) {
				code.overwrite(_element.argument.start, _element.argument.end, argumentsArrayAlias);
			}

			firstSpreadIndex = i;
		}
	}

	if (firstSpreadIndex === -1) return false; // false indicates no spread elements

	if (isNew) {
		for (i = 0; i < elements.length; i += 1) {
			var _element2 = elements[i];
			if (_element2.type === 'SpreadElement') {
				code.remove(_element2.start, _element2.argument.start);
			} else {
				code.prependRight(_element2.start, '[');
				code.prependRight(_element2.end, ']');
			}
		}

		return true; // true indicates some spread elements
	}

	var element = elements[firstSpreadIndex];
	var previousElement = elements[firstSpreadIndex - 1];

	if (!previousElement) {
		code.remove(start, element.start);
		code.overwrite(element.end, elements[1].start, '.concat( ');
	} else {
		code.overwrite(previousElement.end, element.start, ' ].concat( ');
	}

	for (i = firstSpreadIndex; i < elements.length; i += 1) {
		element = elements[i];

		if (element) {
			if (element.type === 'SpreadElement') {
				code.remove(element.start, element.argument.start);
			} else {
				code.appendLeft(element.start, '[');
				code.appendLeft(element.end, ']');
			}
		}
	}

	return true; // true indicates some spread elements
}